import glob
import os

import pandas as pd

def simple_CTC(annotations: pd.DataFrame,
        #duration: int,
        interlocutors_1=('CHI',),
        interlocutors_2=('FEM', 'MAL', 'OCH'),
        max_interval=1000,
        min_delay=0,
        **kwargs):
    """number of conversational turn counts based on vocalizations occurring
    in a given interval of one another

    keyword arguments:
        - interlocutors_1 : first group of interlocutors, default = ['CHI']
        - interlocutors_2 : second group of interlocutors, default = ['FEM','MAL','OCH']
        - max_interval : maximum interval in ms for it to be considered a turn, default = 1000
        - min_delay : minimum delay between somebody starting speaking
    """
    # build the interactants groups, every label in interlocutors_1 can interact with interlocutors_2 and vice versa
    print(annotations)
    speakers = set(interlocutors_1 + interlocutors_2)
    interactants = {k: set(interlocutors_2) for k in interlocutors_1}
    for k in interlocutors_2:
        if k in interactants:
            interactants[k] = interactants[k] | set(interlocutors_1)
        else:
            interactants[k] = set(interlocutors_1)

    annotations = annotations[annotations["speaker_type"].isin(speakers)].copy()

    if annotations.shape[0]:
        # store the duration between vocalizations
        annotations["iti"] = annotations["segment_onset"] - annotations["segment_offset"].shift(1)
        # store the previous speaker
        annotations["prev_speaker_type"] = annotations["speaker_type"].shift(1)

        annotations["delay"] = annotations["segment_onset"] - annotations["segment_onset"].shift(1)

        # not using absolute value for 'iti' is a choice and should be evaluated (we allow speakers to 'interrupt'
        # themselves
        annotations["is_CT"] = (
                (annotations.apply(lambda row: row["prev_speaker_type"] in interactants[row['speaker_type']], axis=1))
                &
                (annotations['iti'] < max_interval)
                &
                (annotations['delay'] >= min_delay)
        )

        return annotations#['is_CT'].sum()
    else:
        return 0

def voc_speaker(annotations: pd.DataFrame, duration: int, **kwargs):
    """number of vocalizations for a given speaker type

    Required keyword arguments:
        - speaker : speaker_type to use
    """
    return annotations[annotations["speaker_type"] == kwargs["speaker"]].shape[0]

def voc_speaker_ph(annotations: pd.DataFrame, duration: int, **kwargs):
    """number of vocalizations per hour for a given speaker type

    Required keyword arguments:
        - speaker : speaker_type to use
    """
    return annotations[annotations["speaker_type"] == kwargs["speaker"]].shape[0] * (3600000 / duration)

def voc_dur_speaker_ph(annotations: pd.DataFrame, duration: int, **kwargs):
    """total duration of vocalizations by a given speaker type in milliseconds per hour

    Required keyword arguments:
        - speaker : speaker_type to use
    """
    return annotations[annotations["speaker_type"] == kwargs["speaker"]]["duration"].sum() * (3600000 / duration)

def avg_voc_dur_speaker(annotations: pd.DataFrame, duration: int, **kwargs):
    """average duration in milliseconds of vocalizations for a given speaker type

    Required keyword arguments:
        - speaker : speaker_type to use
    """
    return annotations[annotations["speaker_type"] == kwargs["speaker"]]["duration"].mean()




###
for f in glob.glob('../annotations/vtc/converted/*/*.csv'):
    annotations = pd.read_csv(f)
    path = '../turn-taking/'
    os.makedirs(path, exist_ok=True)
    turns = simple_CTC(annotations)
    turns_fem =
    turns.to_csv(path + os.path.basename(f))
    print(simple_CTC(annotations))